@@ -16,6 +16,8 @@
 #' @param index.file The bai index. This is expected without the .bai file
 #' suffix, see \code{?scanBam}.
 #' @param keep.duplicates Keep or remove duplicated reads.
+#' @param chunks Split \code{interval.file} into specified number of chunks
+#' to reduce memory usage.
 #' @param ... Additional parameters passed to \code{ScanBamParam}.
 #' @return Returns total and average coverage by intervals.
 #' @author Markus Riester
@@ -39,36 +41,64 @@
 #'             scanBam scanFa scanFaIndex TabixFile
 calculateBamCoverageByInterval <- function(bam.file, interval.file,
     output.file = NULL, index.file = bam.file, keep.duplicates = FALSE,
-    ...) {
-    intervalGr <- readIntervalFile(interval.file, strict = FALSE,
+    chunks = 20, ...) {
+    flog.debug("Used Ncells/Vcells: %s (Mb)",
+        paste(suppressMessages(gc()[,2]), collapse = "/"))
+
+    intervalGrAll <- readIntervalFile(interval.file, strict = FALSE,
         verbose = FALSE)
+    # skip splitting with small panels
+    if (is.null(chunks) || is.na(chunks) || chunks < 2 ||
+        length(intervalGrAll) < chunks * 50) {
+        chunkIds <- rep(1, length(intervalGrAll))
+    } else {
+        chunkIds <- cut(seq_along(intervalGrAll), chunks, labels = FALSE)
+    }
+    .calculateBamCoverageByInterval <- function(intervalGr, ...) {
+        param <- ScanBamParam(what = c("pos", "qwidth", "flag"),
+                    which = intervalGr,
+                    flag = scanBamFlag(isUnmappedQuery = FALSE,
+                                 isNotPassingQualityControls = FALSE,
+                                 isSecondaryAlignment = FALSE,
+                                 isDuplicate = NA
+                         ),
+                    ...
+                 )
 
-    param <- ScanBamParam(what = c("pos", "qwidth", "flag"),
-                which = intervalGr,
-                flag = scanBamFlag(isUnmappedQuery = FALSE,
-                             isNotPassingQualityControls = FALSE,
-                             isSecondaryAlignment = FALSE,
-                             isDuplicate = NA
-                     ),
-                ...
-             )
+        xAll <- scanBam(bam.file, index = index.file, param = param)
+        xDupFiltered <- .filterDuplicates(xAll)
 
-    xAll <- scanBam(bam.file, index = index.file, param = param)
-    xDupFiltered <- .filterDuplicates(xAll)
+        x <- xDupFiltered
+        if (keep.duplicates) x <- xAll
 
-    x <- xDupFiltered
-    if (keep.duplicates) x <- xAll
+        intervalGr$coverage <- vapply(seq_along(x), function(i)
+            sum(coverage(IRanges(x[[i]][["pos"]], width = x[[i]][["qwidth"]]),
+                shift = -start(intervalGr)[i], width = width(intervalGr)[i])), integer(1))
 
-    intervalGr$coverage <- vapply(seq_along(x), function(i)
-        sum(coverage(IRanges(x[[i]][["pos"]], width = x[[i]][["qwidth"]]),
-            shift = -start(intervalGr)[i], width = width(intervalGr)[i])), integer(1))
+        intervalGr$average.coverage <- intervalGr$coverage / width(intervalGr)
 
-    intervalGr$average.coverage <- intervalGr$coverage / width(intervalGr)
+        intervalGr$counts <- as.numeric(vapply(x, function(y) length(y$pos), integer(1)))
+        intervalGr$duplication.rate <- 1 -
+            vapply(xDupFiltered, function(y) length(y$pos), integer(1)) /
+            vapply(xAll, function(y) length(y$pos), integer(1))
 
-    intervalGr$counts <- as.numeric(vapply(x, function(y) length(y$pos), integer(1)))
-    intervalGr$duplication.rate <- 1 -
-        vapply(xDupFiltered, function(y) length(y$pos), integer(1)) /
-        vapply(xAll, function(y) length(y$pos), integer(1))
+        flog.debug("Used Ncells/Vcells: %s (Mb)",
+            paste(suppressMessages(gc()[,2]), collapse = "/"))
+        
+        x <- xAll <- xDupFiltered <- NULL    
+        intervalGr
+    }
+    intervalGrAll <- split(intervalGrAll, chunkIds)
+
+    intervalGr <- unlist(GRangesList(
+        lapply(seq_along(intervalGrAll), function(i) {
+            if (length(intervalGrAll) > 1) {
+                flog.info("Processing %s (%i/%i)...", as.character(intervalGrAll[[i]][1]),
+                    i, length(intervalGrAll))
+            }
+            .calculateBamCoverageByInterval(intervalGrAll[[i]], ...)
+        }
+    )))
 
     if (!is.null(output.file)) {
         .writeCoverage(intervalGr, output.file)
