@@ -36,14 +36,14 @@
 #' @author Markus Riester
 #' @examples
 #'
-#' normal.coverage.file <- system.file("extdata", "example_normal.txt",
+#' normal.coverage.file <- system.file("extdata", "example_normal.txt.gz",
 #'     package = "PureCN")
-#' normal2.coverage.file <- system.file("extdata", "example_normal2.txt",
+#' normal2.coverage.file <- system.file("extdata", "example_normal2.txt.gz",
 #'     package = "PureCN")
 #' normal.coverage.files <- c(normal.coverage.file, normal2.coverage.file)
 #' normalDB <- createNormalDatabase(normal.coverage.files)
 #'
-#' tumor.coverage.file <- system.file("extdata", "example_tumor.txt",
+#' tumor.coverage.file <- system.file("extdata", "example_tumor.txt.gz",
 #'     package = "PureCN")
 #' vcf.file <- system.file("extdata", "example.vcf.gz",
 #'     package = "PureCN")
@@ -171,6 +171,20 @@ normalDB.min.coverage, normalDB.max.missing) {
     intervalsUsed
 }
 
+.filterIntervalsCentromeres <- function(intervalsUsed, tumor, centromeres) {
+    if (is.null(centromeres)) return(intervalsUsed)
+    nBefore <- sum(intervalsUsed)
+    intervalsUsed <- intervalsUsed & seqnames(tumor) %in% seqlevels(centromeres)
+    nAfter <- sum(intervalsUsed)
+
+    if (nAfter < nBefore) {
+        flog.info("Removing %i intervals on non-standard chromosomes not listed in centromeres (%s).",
+            nBefore - nAfter,
+            paste(seqlevels(tumor)[!seqlevels(tumor) %in% seqlevels(centromeres)], collapse = ","))
+    }
+    intervalsUsed
+}
+
 .filterIntervalsTargetedBase <- function(intervalsUsed, tumor, min.targeted.base) {
     if (is.null(min.targeted.base)) return(intervalsUsed)
     nBefore <- sum(intervalsUsed)
