@@ -8,21 +8,22 @@
 #' function from the VariantAnnotation package.
 #' @param prior.somatic Prior probabilities for somatic mutations. First value
 #' is for the case when no matched normals are available and the variant is not
-#' in dbSNP (second value). Third value is for variants with MuTect somatic
-#' call. Different from 1, because somatic mutations in segments of copy number
-#' 0 have 0 probability and artifacts can thus have dramatic influence on
+#' in germline databases (second value). Third value is for variants with MuTect
+#' somatic call. Different from 1, because somatic mutations in segments of copy
+#' number 0 have 0 probability and artifacts can thus have dramatic influence on
 #' likelihood score. Forth value is for variants not labeled as somatic by
 #' MuTect. Last two values are optional, if vcf contains a flag Cosmic.CNT, it
-#' will set the prior probability for variants with CNT > 2 to the first of
+#' will set the prior probability for variants with CNT > 6 to the first of
 #' those values in case of no matched normal available (0.995 default).  Final
-#' value is for the case that variant is in both dbSNP and COSMIC > 2.
+#' value is for the case that variant is in both germline databases and
+#' COSMIC count > 6.
 #' @param tumor.id.in.vcf Id of tumor in case multiple samples are stored in
 #' VCF.
 #' @param min.cosmic.cnt Minimum number of hits in the COSMIC database to 
 #' call variant as likely somatic.
 #' @param DB.info.flag Flag in INFO of VCF that marks presence in common
 #' germline databases. Defaults to \code{DB} that may contain somatic variants
-#' if it is from an unfiltered dbSNP VCF.
+#' if it is from an unfiltered germline database.
 #' @param Cosmic.CNT.info.field Info field containing hits in the Cosmic database
 #' @return The \code{vcf} with \code{numeric(nrow(vcf))} vector with the
 #' prior probability of somatic status for each variant in the 
@@ -59,14 +60,14 @@ setPriorVcf <- function(vcf, prior.somatic = c(0.5, 0.0005, 0.999, 0.0001,
          if (!is.null(info(vcf)[[Cosmic.CNT.info.field]])) {
              flog.info("Found COSMIC annotation in VCF. Requiring %i hits.", 
                 min.cosmic.cnt)
-             flog.info("Setting somatic prior probabilities for hits to %f or to %f if in both COSMIC and dbSNP.", 
+             flog.info("Setting somatic prior probabilities for hits to %f or to %f if in both COSMIC and likely germline based on dbSNP membership or population allele frequency.", 
                 tmp[5], tmp[6])
 
              prior.somatic[which(info(vcf)[[Cosmic.CNT.info.field]] >= min.cosmic.cnt)] <- tmp[5]
              prior.somatic[which(info(vcf)[[Cosmic.CNT.info.field]] >= min.cosmic.cnt & 
                 info(vcf)[[DB.info.flag]])] <- tmp[6]
          } else {
-             flog.info("Setting somatic prior probabilities for dbSNP hits to %f or to %f otherwise.", 
+             flog.info("Setting somatic prior probabilities for likely germline hits to %f or to %f otherwise.", 
                 tmp[2], tmp[1])
          }      
     }     
